==> rstudio-1.0.143.tar.gz: rstudio-1.0.143/src/gwt/src/org/rstudio/studio/client/workbench/views/output/sourcecpp/events/SourceCppCompletedEvent.java <==
/*
 * SourceCppCompletedEvent.java
 *
 * Copyright (C) 2009-12 by RStudio, Inc.
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */
package org.rstudio.studio.client.workbench.views.output.sourcecpp.events;

import org.rstudio.studio.client.workbench.views.output.sourcecpp.model.SourceCppState;
import com.google.gwt.event.shared.EventHandler;
import com.google.gwt.event.shared.GwtEvent;

public class SourceCppCompletedEvent extends GwtEvent<SourceCppCompletedEvent.Handler>
{
   public interface Handler extends EventHandler
   {
      void onSourceCppCompleted(SourceCppCompletedEvent event);
   }

   public SourceCppCompletedEvent(SourceCppState state)
   {
      state_ = state;
   }
   
   public SourceCppState getState()
   {
      return state_;
   }
   
   @Override
   public Type<Handler> getAssociatedType()
   {
      return TYPE;
   }

   @Override
   protected void dispatch(Handler handler)
   {
      handler.onSourceCppCompleted(this);
   }
   
   private final SourceCppState state_;
  
   public static final Type<Handler> TYPE = new Type<Handler>();
}

==> rstudio-2022.02.3-492.tar.gz: rstudio-2022.02.3-492/src/gwt/src/org/rstudio/studio/client/workbench/views/output/sourcecpp/events/SourceCppCompletedEvent.java <==
/*
 * SourceCppCompletedEvent.java
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */
package org.rstudio.studio.client.workbench.views.output.sourcecpp.events;

import org.rstudio.studio.client.workbench.views.output.sourcecpp.model.SourceCppState;
import com.google.gwt.event.shared.EventHandler;
import com.google.gwt.event.shared.GwtEvent;

public class SourceCppCompletedEvent extends GwtEvent<SourceCppCompletedEvent.Handler>
{
   public interface Handler extends EventHandler
   {
      void onSourceCppCompleted(SourceCppCompletedEvent event);
   }

   public SourceCppCompletedEvent(SourceCppState state)
   {
      state_ = state;
   }

   public SourceCppState getState()
   {
      return state_;
   }

   @Override
   public Type<Handler> getAssociatedType()
   {
      return TYPE;
   }

   @Override
   protected void dispatch(Handler handler)
   {
      handler.onSourceCppCompleted(this);
   }

   private final SourceCppState state_;

   public static final Type<Handler> TYPE = new Type<>();
}
